package config

import (
	"database/sql"
	"fmt"
	"gopkg.in/ini.v1"
	"log"
	"shandong_datapush/common"
	_ "github.com/denisenkom/go-mssqldb"
	_ "github.com/lib/pq"
)

var (
	DBType string
	DBConnInfo *common.DBConnectInfo
	DB *sql.DB
    err error
)

func init() {
	file, err := ini.Load("./config/conf.ini")
	common.ErrorPrintln("读取配置文件异常", err)
	DBType = file.Section("databaseType").Key("type").String()
	DBConnInfo = new(common.DBConnectInfo)
	err = file.Section("databaseConnection").MapTo(DBConnInfo)
	common.ErrorPrintln("数据库连接信息映射异常", err)
}

func DBConnection() {
	if DBType == "postgresql" {
		log.Println("当前使用pg数据库")
		connString := fmt.Sprintf("host=%s port=%s user=%s password=%s dbname=%s sslmode=disable",DBConnInfo.Server, DBConnInfo.Port, DBConnInfo.Username, DBConnInfo.Password, DBConnInfo.DBName)
		DB, err = sql.Open("postgres", connString)
		err = DB.Ping()
		if err != nil {
			log.Fatalf("[Error] PG 数据库连接失败: %s", err.Error())
		}else {
			log.Println("postgres 数据库连接成功！")
		}
	} else if DBType == "sqlserver" {
		log.Println("当前使用SqlServer数据库")
		connString := fmt.Sprintf("server=%s;database=%s;user id=%s;password=%s;port=%s;encrypt=disable", DBConnInfo.Server, DBConnInfo.DBName, DBConnInfo.Username, DBConnInfo.Password, DBConnInfo.Port)
		DB, err = sql.Open("mssql", connString)
		err = DB.Ping()
		if err != nil {
			log.Fatalf("[Error] sqlserver 数据库连接失败: %s", err.Error())
		}else {
			log.Println("sqlserver 数据库连接成功！")
		}
	}
}